@@ -25,7 +25,7 @@ class Command(ScrapyCommand):
             "-r",
             "--rq-api",
             metavar="RQ_API",
-            help=("set rq api uri. " "the default crawler class will be 'rq-demo'"),
+            help=("set rq api uri. " "the default crawler class is 'rq-demo'"),
         )
 
     def process_options(self, args, opts):
